# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.dataset_api import DatasetApi


class TestDatasetApi(unittest.TestCase):
    """DatasetApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DatasetApi()

    def tearDown(self) -> None:
        pass

    def test_create_or_update_entities1(self) -> None:
        """Test case for create_or_update_entities1

        Create or update many
        """
        pass

    def test_create_or_update_entity(self) -> None:
        """Test case for create_or_update_entity

        Create or update one
        """
        pass

    def test_delete_all_entities(self) -> None:
        """Test case for delete_all_entities

        Delete all
        """
        pass

    def test_delete_entity(self) -> None:
        """Test case for delete_entity

        Delete one
        """
        pass


if __name__ == '__main__':
    unittest.main()
