# coding: utf-8

"""
    GraphQL support

    GraphQL endpoint to query Knowledge Graphs

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class WhenOperator(str, Enum):
    """
    The operator for when condition.
    """

    """
    allowed enum values
    """
    ALWAYS = 'ALWAYS'
    EQUALS = 'EQUALS'
    NOT_EQUALS = 'NOT_EQUALS'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of WhenOperator from a JSON string"""
        return cls(json.loads(json_str))


