# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.page_o_auth2_authorized_client import PageOAuth2AuthorizedClient

class TestPageOAuth2AuthorizedClient(unittest.TestCase):
    """PageOAuth2AuthorizedClient unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageOAuth2AuthorizedClient:
        """Test PageOAuth2AuthorizedClient
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PageOAuth2AuthorizedClient`
        """
        model = PageOAuth2AuthorizedClient()
        if include_optional:
            return PageOAuth2AuthorizedClient(
                first = '',
                items = [
                    wordlift_client.models.o_auth2_authorized_client.OAuth2AuthorizedClient(
                        access_token_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        access_token_issued_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        access_token_scopes = '', 
                        access_token_type = '', 
                        access_token_value = '', 
                        client_registration_id = '', 
                        id = 56, 
                        principal_name = '', 
                        refresh_token_issued_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        refresh_token_value = '', )
                    ],
                last = '',
                next = '',
                prev = '',
                var_self = ''
            )
        else:
            return PageOAuth2AuthorizedClient(
                first = '',
                items = [
                    wordlift_client.models.o_auth2_authorized_client.OAuth2AuthorizedClient(
                        access_token_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        access_token_issued_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        access_token_scopes = '', 
                        access_token_type = '', 
                        access_token_value = '', 
                        client_registration_id = '', 
                        id = 56, 
                        principal_name = '', 
                        refresh_token_issued_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        refresh_token_value = '', )
                    ],
                last = '',
                next = '',
                prev = '',
                var_self = '',
        )
        """

    def testPageOAuth2AuthorizedClient(self):
        """Test PageOAuth2AuthorizedClient"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
